"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  default: () => VitePluginGraphQLCodegen
});
module.exports = __toCommonJS(src_exports);
var import_cli = require("@graphql-codegen/cli");

// src/utils/isCodegenConfig.ts
var import_vite = require("vite");
function isCodegenConfig(filePath, context) {
  return (0, import_vite.normalizePath)(filePath) === (0, import_vite.normalizePath)(context.filepath);
}

// src/utils/isGraphQLFile.ts
var import_vite2 = require("vite");
var import_plugin_helpers = require("@graphql-codegen/plugin-helpers");
async function isGraphQLFile(filePath, context) {
  const { documents = [], schema = [] } = context.getConfig();
  const normalized = [
    ...(0, import_plugin_helpers.normalizeInstanceOrArray)(documents),
    ...(0, import_plugin_helpers.normalizeInstanceOrArray)(schema)
  ];
  const loadedDocuments = await context.loadDocuments(normalized);
  if (!loadedDocuments.length)
    return false;
  const paths = loadedDocuments.map(({ location = "" }) => location).map(import_vite2.normalizePath).filter(Boolean);
  if (!paths.length)
    return false;
  return paths.some((documentPath) => documentPath === (0, import_vite2.normalizePath)(filePath));
}

// src/utils/viteModes.ts
var modes = {
  serve: "serve",
  build: "build"
};
var isServeMode = (mode) => mode === modes.serve;
var isBuildMode = (mode) => mode === modes.build;

// src/utils/debugLog.ts
var RESET = "\x1B[0m";
var BRIGHT = "\x1B[1m";
var DIM = "\x1B[2m";
var FG_CYAN = "\x1B[36m";
function debugLog(...args) {
  const LOG_PREFIX = `${FG_CYAN}${BRIGHT}VITE PLUGIN GRAPHQL CODEGEN${RESET} `;
  console.log(LOG_PREFIX, DIM, ...args, RESET);
}

// src/index.ts
function VitePluginGraphQLCodegen(options) {
  let codegenContext;
  let viteMode;
  const {
    runOnStart = true,
    runOnBuild = true,
    enableWatcher = true,
    config = null,
    configOverride = {},
    configOverrideOnStart = {},
    configOverrideOnBuild = {},
    configOverrideWatcher = {},
    configFilePathOverride,
    debug = false
  } = options ?? {};
  const log = (...args) => {
    if (!debug)
      return;
    debugLog(...args);
  };
  const generateWithOverride = async (overrideConfig) => {
    const currentConfig = codegenContext.getConfig();
    return (0, import_cli.generate)({
      ...currentConfig,
      ...configOverride,
      ...overrideConfig,
      watch: false
    });
  };
  log("Plugin initialized with options:", options);
  return {
    name: "graphql-codegen",
    async config(_config, env) {
      try {
        if (config) {
          log("Manual config passed, creating codegen context");
          codegenContext = new import_cli.CodegenContext({ config });
        } else {
          const cwd = process.cwd();
          log("Loading codegen context:", configFilePathOverride ?? cwd);
          codegenContext = await (0, import_cli.loadContext)(configFilePathOverride);
        }
        log("Loading codegen context successful");
      } catch (error) {
        log("Loading codegen context failed");
        throw error;
      }
      viteMode = env.command;
    },
    async buildStart() {
      const isServe = isServeMode(viteMode);
      const isBuild = isBuildMode(viteMode);
      if (isServe && !runOnStart)
        return;
      if (isBuild && !runOnBuild)
        return;
      try {
        if (isServe)
          await generateWithOverride(configOverrideOnStart);
        if (isBuild)
          await generateWithOverride(configOverrideOnBuild);
        isServe && log("Generation successful on start");
        isBuild && log("Generation successful on build");
      } catch (error) {
        isServe && log("Generation failed on start");
        isBuild && log("Generation failed on build");
        if (isBuild)
          throw error;
      }
    },
    configureServer(server) {
      const listener = async (filePath = "") => {
        log("File changed:", filePath);
        const isConfig = isCodegenConfig(filePath, codegenContext);
        if (isConfig) {
          log("Codegen config file changed, restarting vite");
          server.restart();
          return;
        }
        if (!enableWatcher)
          return;
        try {
          const isDocument = await isGraphQLFile(filePath, codegenContext);
          log("Document check successful in file watcher");
          if (!isDocument)
            return;
        } catch (error) {
          log("Document check failed in file watcher");
        }
        log("File matched a graphql document");
        try {
          await generateWithOverride(configOverrideWatcher);
          log("Generation successful in file watcher");
        } catch (error) {
          log("Generation failed in file watcher");
        }
      };
      server.watcher.on("add", listener);
      server.watcher.on("change", listener);
    }
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
//# sourceMappingURL=index.js.map